@@ -8,8 +8,8 @@
 #'   \code{waveband} object; far-red in not defined by \code{"ISO"} standard
 #'   definitions based on human colour vision, and included under red;
 #'   \code{"Smith10"}, \code{"Smith20"}, \code{"Inada"}, \code{"Warrington"},
-#'   \code{"Sellaro"} and \code{"Broad"} are non-standard but used in plant
-#'   sciences; \code{"RedEdge40"} and \code{"RedEdge40"} are non-standard but
+#'   \code{"Sellaro"}, \code{"Broad"} and \code{"Apogee"} are non-standard but used in plant
+#'   sciences; \code{"RedEdge20"} and \code{"RedEdge40"} are non-standard but
 #'   frequently used in remote sensing.
 #'
 #'   In plant photobiology the definitions proposed by Prof. Harry Smith are the
@@ -17,7 +17,8 @@
 #'   relevant to phytochrome photoreceptors. However, other authors have used
 #'   different definitions in their publications. "Smith10" (725-735 nm),
 #'   "Smith20" (720-740 nm), "Inada" (700-800 nm), "Warrington" (700-850 nm),
-#'   and "Sellaro" (700-750 nm).
+#'   and "Sellaro" (700-750 nm). "Apogee" is a definition given by a sensor
+#'   manufacturer that matches "Smith20" for far-red.
 #'
 #'   Other definitions used in remote sensing. For example the "red edge" is to
 #'   detect the condition of vegetation based on light reflectance by green
@@ -97,7 +98,7 @@ Far_red <- function(std="ISO") {
   if (std=="ISO") {
     message("'ISO gives no standard definition of far-red.")
     waveband()
-  } else if (std=="Smith20") {
+  } else if (std %in% c("Smith20", "Apogee")) {
     new_waveband(720, 740, wb.name=paste("FarRed", std, sep="."), wb.label=label)
   } else if (std=="Smith10") {
     new_waveband(725, 735, wb.name=paste("FarRed", std, sep="."), wb.label=label)
@@ -111,6 +112,8 @@ Far_red <- function(std="ISO") {
     new_waveband(705, 745, wb.name=paste("FarRed", std, sep="."), wb.label=label)
   } else if (std=="RedEdge20") {
     new_waveband(715, 735, wb.name=paste("FarRed", std, sep="."), wb.label=label)
+  } else if (tolower(std) == "broad") {
+    new_waveband(700, 800, wb.name= "FarRed.broad", wb.label=label)
   } else {
     warning("'std' argument value not implemented.")
     waveband()
